========
flatland
========




.. image:: https://gitlab.aicrowd.com/flatland/flatland/badges/master/pipeline.svg
     :target: https://gitlab.aicrowd.com/flatland/flatland/pipelines
     :alt: Test Running
.. image:: https://gitlab.aicrowd.com/flatland/flatland/badges/master/coverage.svg
     :target: https://gitlab.aicrowd.com/flatland/flatland/pipelines
     :alt: Test Coverage     



Multi Agent Reinforcement Learning on Trains



Features
--------

* TODO

Authors
--------
* Sharada Mohanty <mohanty@aicrowd.com>
* <please-fill-in>